綠界電子發票 Python 3
=====================


綠界電子發票建置中...

安裝
----

利用pip

.. code-block:: python

    pip install ecpay_invoice3


匯入模組

.. code-block:: python

    from ecpay_invoice.ecpay_main import *


其他範例請看demo

change log:

2018-08-14 v1.0.7 修正ItemTaxtType非必填，修正執行第二次初始字典會被修改問題。

2018-08-13 v1.0.6 更新CustomerName最大可以到60個字

2018-07-30 v1.0 Python3 初版



